import { BandOptions } from '../types';
import { Ordinal } from './ordinal';
/**
 * Band 比例尺
 *
 * 一种特殊的 ordinal scale，区别在于值域的范围是连续的。
 * 使用的场景例如柱状图，可以用来定位各个柱子水平方向距离原点开始绘制的距离、各柱子之间的间距
 *
 * 由于部分选项较为抽象，见下图描述：
 *
 * PO = paddingOuter
 * PI = paddingInner
 *
 * domain = [A, B]
 *
 * |<------------------------------------------- range ------------------------------------------->|
 * |             |                   |             |                   |             |             |
 * |<--step*PO-->|<----bandWidth---->|<--step*PI-->|<----bandWidth---->|<--step*PI-->|<--step*PO-->|
 * |             | ***************** |             | ***************** |             |             |
 * |             | ******* A ******* |             | ******* B ******* |             |             |
 * |             | ***************** |             | ***************** |             |             |
 * |             |<--------------step------------->|                                               |
 * |-----------------------------------------------------------------------------------------------|
 *
 * 性能方便较 d3 快出 8 - 9 倍
 */
export declare class Band<O extends BandOptions = BandOptions> extends Ordinal<O> {
    private step;
    private bandWidth;
    private adjustedRange;
    protected getDefaultOptions(): O;
    constructor(options?: BandOptions);
    clone(): Band<O>;
    getStep(): number;
    getBandWidth(): number;
    getRange(): O["range"];
    protected getPaddingInner(): number;
    protected getPaddingOuter(): number;
    protected rescale(): void;
}
